@@ -29,7 +29,16 @@ class HoofdLocationSet(LocationSetBase):
     @property
     def validation_rules(self):
         return [
-            {"parameter": "H.S.", "extreme_values": {"hmax": "HS1_HMAX", "hmin": "HS1_HMIN"},},
-            {"parameter": "H2.S.", "extreme_values": {"hmax": "HS2_HMAX", "hmin": "HS2_HMIN"},},
-            {"parameter": "H3.S.", "extreme_values": {"hmax": "HS3_HMAX", "hmin": "HS3_HMIN"},},
+            {
+                "parameter": "H.S.",
+                "extreme_values": {"hmax": "HS1_HMAX", "hmin": "HS1_HMIN"},
+            },
+            {
+                "parameter": "H2.S.",
+                "extreme_values": {"hmax": "HS2_HMAX", "hmin": "HS2_HMIN"},
+            },
+            {
+                "parameter": "H3.S.",
+                "extreme_values": {"hmax": "HS3_HMAX", "hmin": "HS3_HMIN"},
+            },
         ]
