@@ -5,8 +5,10 @@ from hdsr_wis_config_reader.readers.config_reader import FewsConfigReader
 import pytest
 
 
-@pytest.fixture()
-def fews_config() -> FewsConfigReader:
+@pytest.fixture(
+    scope="session"
+)  # 'session', so we cache the fixture for all tests (instead of default 'function')
+def fews_config_local() -> FewsConfigReader:
     # we use config saved in this repo (=static), instead of downloading from repo 'wis_config'
     assert constants.WIS_CONFIG_TEST_DIR.is_dir()
     fews_config = FewsConfigReader(path=constants.WIS_CONFIG_TEST_DIR)
@@ -20,7 +22,9 @@ def loc_sets() -> LocationSetCollection:
     return loc_sets
 
 
-WIS_CONFIG_TEST_DIR = constants.BASE_DIR / "tests" / "data" / "input" / "config_wis60prd_202002"
+WIS_CONFIG_TEST_DIR = (
+    constants.BASE_DIR / "tests" / "data" / "input" / "config_wis60prd_202002"
+)
 
 
 def test_test_dir_exists():
