@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants import paths
+from hdsr_wis_config_reader import constants
 from hdsr_wis_config_reader.tests.fixtures import loc_sets
 
 import pandas as pd  # noqa pandas comes with geopandas
@@ -42,15 +42,20 @@ expected_csvfile_meta = {
 
 
 def test_pslocationset(loc_sets):
-    assert loc_sets.psloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.psloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
     assert loc_sets.psloc.idmap_section_name == expected_idmap_section_name
     assert loc_sets.psloc.name == expected_name
     assert loc_sets.psloc.csv_filename == expected_csvfile
     assert loc_sets.psloc.fews_name == expected_fews_name
-    assert loc_sets.psloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert (
+        loc_sets.psloc.get_validation_attributes(int_pars=None)
+        == expected_validation_attributes
+    )
     assert loc_sets.psloc.validation_rules == expected_validation_rules
     assert loc_sets.psloc.csv_file_meta == expected_csvfile_meta
     assert loc_sets.psloc.attrib_files == expected_attrib_files
     assert isinstance(loc_sets.psloc.geo_df, pd.DataFrame)
     assert isinstance(loc_sets.psloc.geo_df_original, pd.DataFrame)
-    pd.testing.assert_frame_equal(left=loc_sets.psloc.geo_df, right=loc_sets.psloc.geo_df_original)
+    pd.testing.assert_frame_equal(
+        left=loc_sets.psloc.geo_df, right=loc_sets.psloc.geo_df_original
+    )
