@@ -75,8 +75,14 @@ expected_csvfile_meta = {
             "csvFile": "oppvlwater_langsprofielen",
             "id": "%LOC_ID%",
             "attribute": [
-                {"number": "%Langsprofiel_Kromme_Rijn%", "id": "Langsprofiel_Kromme_Rijn",},
-                {"number": "%Langsprofiel_Caspargouwse_Wetering%", "id": "Langsprofiel_Caspargouwse_Wetering",},
+                {
+                    "number": "%Langsprofiel_Kromme_Rijn%",
+                    "id": "Langsprofiel_Kromme_Rijn",
+                },
+                {
+                    "number": "%Langsprofiel_Caspargouwse_Wetering%",
+                    "id": "Langsprofiel_Caspargouwse_Wetering",
+                },
                 {
                     "number": "%Langsprofiel_Stadswater_Utrecht_en_Vecht%",
                     "id": "Langsprofiel_Stadswater_Utrecht_en_Vecht",
@@ -85,21 +91,51 @@ expected_csvfile_meta = {
                     "number": "%Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel%",
                     "id": "Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel",
                 },
-                {"number": "%Langsprofiel_Oude_Rijn_boezem_Oost%", "id": "Langsprofiel_Oude_Rijn_boezem_Oost",},
-                {"number": "%Langsprofiel_Oude_Rijn_boezem_West%", "id": "Langsprofiel_Oude_Rijn_boezem_West",},
+                {
+                    "number": "%Langsprofiel_Oude_Rijn_boezem_Oost%",
+                    "id": "Langsprofiel_Oude_Rijn_boezem_Oost",
+                },
+                {
+                    "number": "%Langsprofiel_Oude_Rijn_boezem_West%",
+                    "id": "Langsprofiel_Oude_Rijn_boezem_West",
+                },
                 {"number": "%Langsprofiel_Grecht%", "id": "Langsprofiel_Grecht"},
                 {
                     "number": "%Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering%",
                     "id": "Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering",
                 },
-                {"number": "%Langsprofiel_Dubbele_Wiericke%", "id": "Langsprofiel_Dubbele_Wiericke",},
-                {"number": "%Langsprofiel_Leidsche_Rijn%", "id": "Langsprofiel_Leidsche_Rijn",},
-                {"number": "%Langsprofiel_Amsterdam-Rijnkanaal%", "id": "Langsprofiel_Amsterdam-Rijnkanaal",},
-                {"number": "%Langsprofiel_Merwedekanaal%", "id": "Langsprofiel_Merwedekanaal",},
-                {"number": "%Langsprofiel_Boezem_AGV%", "id": "Langsprofiel_Boezem_AGV",},
-                {"number": "%Langsprofiel_Langbroekerwetering%", "id": "Langsprofiel_Langbroekerwetering",},
-                {"number": "%Langsprofiel_Amerongerwetering%", "id": "Langsprofiel_Amerongerwetering",},
-                {"number": "%Langsprofiel_Schalkwijkse_wetering%", "id": "Langsprofiel_Schalkwijkse_wetering",},
+                {
+                    "number": "%Langsprofiel_Dubbele_Wiericke%",
+                    "id": "Langsprofiel_Dubbele_Wiericke",
+                },
+                {
+                    "number": "%Langsprofiel_Leidsche_Rijn%",
+                    "id": "Langsprofiel_Leidsche_Rijn",
+                },
+                {
+                    "number": "%Langsprofiel_Amsterdam-Rijnkanaal%",
+                    "id": "Langsprofiel_Amsterdam-Rijnkanaal",
+                },
+                {
+                    "number": "%Langsprofiel_Merwedekanaal%",
+                    "id": "Langsprofiel_Merwedekanaal",
+                },
+                {
+                    "number": "%Langsprofiel_Boezem_AGV%",
+                    "id": "Langsprofiel_Boezem_AGV",
+                },
+                {
+                    "number": "%Langsprofiel_Langbroekerwetering%",
+                    "id": "Langsprofiel_Langbroekerwetering",
+                },
+                {
+                    "number": "%Langsprofiel_Amerongerwetering%",
+                    "id": "Langsprofiel_Amerongerwetering",
+                },
+                {
+                    "number": "%Langsprofiel_Schalkwijkse_wetering%",
+                    "id": "Langsprofiel_Schalkwijkse_wetering",
+                },
             ],
         },
         {
@@ -111,7 +147,10 @@ expected_csvfile_meta = {
             "csvFile": "oppvlwater_waterstanden_cacb.csv",
             "id": "%LOC_ID%",
             "relation": {"relatedLocationId": "%REL_CACB%", "id": "REL_CACB"},
-            "attribute": [{"number": "%COEF_CA%", "id": "COEF_CA"}, {"number": "%COEF_CB%", "id": "COEF_CB"},],
+            "attribute": [
+                {"number": "%COEF_CA%", "id": "COEF_CA"},
+                {"number": "%COEF_CB%", "id": "COEF_CB"},
+            ],
         },
         {
             "csvFile": "oppvlwater_waterstanden_validations.csv",
@@ -178,34 +217,70 @@ expected_attrib_files_1 = [
         "id": "%LOC_ID%",
         "attribute": [
             {"number": "%Langsprofiel_Kromme_Rijn%", "id": "Langsprofiel_Kromme_Rijn"},
-            {"number": "%Langsprofiel_Caspargouwse_Wetering%", "id": "Langsprofiel_Caspargouwse_Wetering",},
-            {"number": "%Langsprofiel_Stadswater_Utrecht_en_Vecht%", "id": "Langsprofiel_Stadswater_Utrecht_en_Vecht",},
+            {
+                "number": "%Langsprofiel_Caspargouwse_Wetering%",
+                "id": "Langsprofiel_Caspargouwse_Wetering",
+            },
+            {
+                "number": "%Langsprofiel_Stadswater_Utrecht_en_Vecht%",
+                "id": "Langsprofiel_Stadswater_Utrecht_en_Vecht",
+            },
             {
                 "number": "%Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel%",
                 "id": "Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel",
             },
-            {"number": "%Langsprofiel_Oude_Rijn_boezem_Oost%", "id": "Langsprofiel_Oude_Rijn_boezem_Oost",},
-            {"number": "%Langsprofiel_Oude_Rijn_boezem_West%", "id": "Langsprofiel_Oude_Rijn_boezem_West",},
+            {
+                "number": "%Langsprofiel_Oude_Rijn_boezem_Oost%",
+                "id": "Langsprofiel_Oude_Rijn_boezem_Oost",
+            },
+            {
+                "number": "%Langsprofiel_Oude_Rijn_boezem_West%",
+                "id": "Langsprofiel_Oude_Rijn_boezem_West",
+            },
             {"number": "%Langsprofiel_Grecht%", "id": "Langsprofiel_Grecht"},
             {
                 "number": "%Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering%",
                 "id": "Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering",
             },
-            {"number": "%Langsprofiel_Dubbele_Wiericke%", "id": "Langsprofiel_Dubbele_Wiericke",},
-            {"number": "%Langsprofiel_Leidsche_Rijn%", "id": "Langsprofiel_Leidsche_Rijn",},
-            {"number": "%Langsprofiel_Amsterdam-Rijnkanaal%", "id": "Langsprofiel_Amsterdam-Rijnkanaal",},
-            {"number": "%Langsprofiel_Merwedekanaal%", "id": "Langsprofiel_Merwedekanaal",},
+            {
+                "number": "%Langsprofiel_Dubbele_Wiericke%",
+                "id": "Langsprofiel_Dubbele_Wiericke",
+            },
+            {
+                "number": "%Langsprofiel_Leidsche_Rijn%",
+                "id": "Langsprofiel_Leidsche_Rijn",
+            },
+            {
+                "number": "%Langsprofiel_Amsterdam-Rijnkanaal%",
+                "id": "Langsprofiel_Amsterdam-Rijnkanaal",
+            },
+            {
+                "number": "%Langsprofiel_Merwedekanaal%",
+                "id": "Langsprofiel_Merwedekanaal",
+            },
             {"number": "%Langsprofiel_Boezem_AGV%", "id": "Langsprofiel_Boezem_AGV"},
-            {"number": "%Langsprofiel_Langbroekerwetering%", "id": "Langsprofiel_Langbroekerwetering",},
-            {"number": "%Langsprofiel_Amerongerwetering%", "id": "Langsprofiel_Amerongerwetering",},
-            {"number": "%Langsprofiel_Schalkwijkse_wetering%", "id": "Langsprofiel_Schalkwijkse_wetering",},
+            {
+                "number": "%Langsprofiel_Langbroekerwetering%",
+                "id": "Langsprofiel_Langbroekerwetering",
+            },
+            {
+                "number": "%Langsprofiel_Amerongerwetering%",
+                "id": "Langsprofiel_Amerongerwetering",
+            },
+            {
+                "number": "%Langsprofiel_Schalkwijkse_wetering%",
+                "id": "Langsprofiel_Schalkwijkse_wetering",
+            },
         ],
     },
     {
         "csvFile": "oppvlwater_waterstanden_cacb.csv",
         "id": "%LOC_ID%",
         "relation": {"relatedLocationId": "%REL_CACB%", "id": "REL_CACB"},
-        "attribute": [{"number": "%COEF_CA%", "id": "COEF_CA"}, {"number": "%COEF_CB%", "id": "COEF_CB"},],
+        "attribute": [
+            {"number": "%COEF_CA%", "id": "COEF_CA"},
+            {"number": "%COEF_CB%", "id": "COEF_CB"},
+        ],
     },
     {
         "csvFile": "oppvlwater_waterstanden_validations.csv",
@@ -246,34 +321,70 @@ expected_attrib_files = [
         "id": "%LOC_ID%",
         "attribute": [
             {"number": "%Langsprofiel_Kromme_Rijn%", "id": "Langsprofiel_Kromme_Rijn"},
-            {"number": "%Langsprofiel_Caspargouwse_Wetering%", "id": "Langsprofiel_Caspargouwse_Wetering",},
-            {"number": "%Langsprofiel_Stadswater_Utrecht_en_Vecht%", "id": "Langsprofiel_Stadswater_Utrecht_en_Vecht",},
+            {
+                "number": "%Langsprofiel_Caspargouwse_Wetering%",
+                "id": "Langsprofiel_Caspargouwse_Wetering",
+            },
+            {
+                "number": "%Langsprofiel_Stadswater_Utrecht_en_Vecht%",
+                "id": "Langsprofiel_Stadswater_Utrecht_en_Vecht",
+            },
             {
                 "number": "%Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel%",
                 "id": "Langsprofiel_Doorslag-Gekanaliseerde_Hollandse_IJssel",
             },
-            {"number": "%Langsprofiel_Oude_Rijn_boezem_Oost%", "id": "Langsprofiel_Oude_Rijn_boezem_Oost",},
-            {"number": "%Langsprofiel_Oude_Rijn_boezem_West%", "id": "Langsprofiel_Oude_Rijn_boezem_West",},
+            {
+                "number": "%Langsprofiel_Oude_Rijn_boezem_Oost%",
+                "id": "Langsprofiel_Oude_Rijn_boezem_Oost",
+            },
+            {
+                "number": "%Langsprofiel_Oude_Rijn_boezem_West%",
+                "id": "Langsprofiel_Oude_Rijn_boezem_West",
+            },
             {"number": "%Langsprofiel_Grecht%", "id": "Langsprofiel_Grecht"},
             {
                 "number": "%Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering%",
                 "id": "Langsprofiel_Lange_Linschoten_tm_Jaap_Bijzerwetering",
             },
-            {"number": "%Langsprofiel_Dubbele_Wiericke%", "id": "Langsprofiel_Dubbele_Wiericke",},
-            {"number": "%Langsprofiel_Leidsche_Rijn%", "id": "Langsprofiel_Leidsche_Rijn",},
-            {"number": "%Langsprofiel_Amsterdam-Rijnkanaal%", "id": "Langsprofiel_Amsterdam-Rijnkanaal",},
-            {"number": "%Langsprofiel_Merwedekanaal%", "id": "Langsprofiel_Merwedekanaal",},
+            {
+                "number": "%Langsprofiel_Dubbele_Wiericke%",
+                "id": "Langsprofiel_Dubbele_Wiericke",
+            },
+            {
+                "number": "%Langsprofiel_Leidsche_Rijn%",
+                "id": "Langsprofiel_Leidsche_Rijn",
+            },
+            {
+                "number": "%Langsprofiel_Amsterdam-Rijnkanaal%",
+                "id": "Langsprofiel_Amsterdam-Rijnkanaal",
+            },
+            {
+                "number": "%Langsprofiel_Merwedekanaal%",
+                "id": "Langsprofiel_Merwedekanaal",
+            },
             {"number": "%Langsprofiel_Boezem_AGV%", "id": "Langsprofiel_Boezem_AGV"},
-            {"number": "%Langsprofiel_Langbroekerwetering%", "id": "Langsprofiel_Langbroekerwetering",},
-            {"number": "%Langsprofiel_Amerongerwetering%", "id": "Langsprofiel_Amerongerwetering",},
-            {"number": "%Langsprofiel_Schalkwijkse_wetering%", "id": "Langsprofiel_Schalkwijkse_wetering",},
+            {
+                "number": "%Langsprofiel_Langbroekerwetering%",
+                "id": "Langsprofiel_Langbroekerwetering",
+            },
+            {
+                "number": "%Langsprofiel_Amerongerwetering%",
+                "id": "Langsprofiel_Amerongerwetering",
+            },
+            {
+                "number": "%Langsprofiel_Schalkwijkse_wetering%",
+                "id": "Langsprofiel_Schalkwijkse_wetering",
+            },
         ],
     },
     {
         "csvFile": "oppvlwater_waterstanden_cacb.csv",
         "id": "%LOC_ID%",
         "relation": {"relatedLocationId": "%REL_CACB%", "id": "REL_CACB"},
-        "attribute": [{"number": "%COEF_CA%", "id": "COEF_CA"}, {"number": "%COEF_CB%", "id": "COEF_CB"},],
+        "attribute": [
+            {"number": "%COEF_CA%", "id": "COEF_CA"},
+            {"number": "%COEF_CB%", "id": "COEF_CB"},
+        ],
     },
     {
         "csvFile": "oppvlwater_waterstanden_validations.csv",
@@ -341,12 +452,17 @@ def test_waterstandlocationset(loc_sets):
     assert loc_sets.waterstandloc.name == expected_name
     assert loc_sets.waterstandloc.csv_filename == expected_csvfile
     assert loc_sets.waterstandloc.fews_name == expected_fews_name
-    assert loc_sets.waterstandloc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert (
+        loc_sets.waterstandloc.get_validation_attributes(int_pars=None)
+        == expected_validation_attributes
+    )
     assert loc_sets.waterstandloc.validation_rules == expected_validation_rules
     assert loc_sets.waterstandloc.csv_file_meta == expected_csvfile_meta
     assert loc_sets.waterstandloc.attrib_files == expected_attrib_files
     assert isinstance(loc_sets.waterstandloc.geo_df, pd.DataFrame)
     assert isinstance(loc_sets.waterstandloc.geo_df_original, pd.DataFrame)
-    pd.testing.assert_frame_equal(left=loc_sets.waterstandloc.geo_df, right=loc_sets.waterstandloc.geo_df_original)
+    pd.testing.assert_frame_equal(
+        left=loc_sets.waterstandloc.geo_df, right=loc_sets.waterstandloc.geo_df_original
+    )
     assert "Z" in loc_sets.waterstandloc.geo_df
     assert not loc_sets.waterstandloc.geo_df["Z"].hasnans
